# thousandeyes-sdk-usage

These usage endpoints define the following operations:

* **Usage**: Retrieve usage data for the specified time period (default is one month).
    
    * Users must have the `View organization usage` permission to access this endpoint.
    * This operation offers visibility across all account groups within the organization.
    * Users with `View organization usage` permission in multiple organizations should query the operation with the `aid` query string parameter (see optional parameters) for each organization.

* **Quotas**: Obtain organization and account usage quotas. Additionally, users with the appropriate permissions can create, update, or delete these quotas.
    
    * Users must have the necessary permissions to perform quota-related actions.

Refer to the Usage API operations for detailed usage instructions and optional parameters.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 7.0.52
- Generator version: 7.6.0
- Build package: com.thousandeyes.api.codegen.ThousandeyesPythonGenerator

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

Install directly via PyPi:

```sh
pip install thousandeyes-sdk-usage
```
(you may need to run `pip` with root permission: `sudo pip install thousandeyes-sdk-usage`)

Then import the package:
```python
import thousandeyes_sdk.usage
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import thousandeyes_sdk.usage
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the installation procedure and then run the following:

```python

import thousandeyes_sdk.core
import thousandeyes_sdk.usage
from thousandeyes_sdk.core.exceptions import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.thousandeyes.com/v7
# See configuration.py for a list of all supported configuration parameters.
configuration = thousandeyes_sdk.core.Configuration(
    host = "https://api.thousandeyes.com/v7"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: BearerAuth
configuration = thousandeyes_sdk.core.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with thousandeyes_sdk.core.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = thousandeyes_sdk.usage.QuotasApi(api_client)
    organizations_quotas_assign = thousandeyes_sdk.usage.OrganizationsQuotasAssign() # OrganizationsQuotasAssign |  (optional)

    try:
        # Create or update accout group quotas
        api_response = api_instance.assign_organizations_account_groups_quotas(organizations_quotas_assign=organizations_quotas_assign)
        print("The response of QuotasApi->assign_organizations_account_groups_quotas:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling QuotasApi->assign_organizations_account_groups_quotas: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.thousandeyes.com/v7*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*QuotasApi* | [**assign_organizations_account_groups_quotas**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/QuotasApi.md#assign_organizations_account_groups_quotas) | **POST** /quotas/account-groups/assign | Create or update accout group quotas
*QuotasApi* | [**assign_organizations_quotas**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/QuotasApi.md#assign_organizations_quotas) | **POST** /quotas/assign | Create or update organizations quotas
*QuotasApi* | [**get_quotas**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/QuotasApi.md#get_quotas) | **GET** /quotas | Get organization and account group usage quota
*QuotasApi* | [**unassign_organizations_account_groups_quotas**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/QuotasApi.md#unassign_organizations_account_groups_quotas) | **POST** /quotas/account-groups/unassign | Remove account group quotas from organizations
*QuotasApi* | [**unassign_organizations_quotas**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/QuotasApi.md#unassign_organizations_quotas) | **POST** /quotas/unassign | Remove organization quotas
*UsageApi* | [**get_enterprise_agents_units_usage**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/UsageApi.md#get_enterprise_agents_units_usage) | **GET** /usage/units/enterprise-agents | Get enterprise agent usage
*UsageApi* | [**get_tests_units_usage**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/UsageApi.md#get_tests_units_usage) | **GET** /usage/units/tests | Get cloud and enterprise agents units usage
*UsageApi* | [**get_usage**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/UsageApi.md#get_usage) | **GET** /usage | Get usage information for the last month


## Documentation For Models

 - [AccountGroupQuota](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/AccountGroupQuota.md)
 - [AllocationUnitUsageBreakdown](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/AllocationUnitUsageBreakdown.md)
 - [EndpointAgentsEmbedded](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/EndpointAgentsEmbedded.md)
 - [EndpointAgentsEssentials](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/EndpointAgentsEssentials.md)
 - [EndpointAgentsUsage](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/EndpointAgentsUsage.md)
 - [EnterpriseAgentUnits](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/EnterpriseAgentUnits.md)
 - [EnterpriseAgentUnitsByTestOwnerAccountGroup](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/EnterpriseAgentUnitsByTestOwnerAccountGroup.md)
 - [EnterpriseAgents](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/EnterpriseAgents.md)
 - [EnterpriseAgentsUsage](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/EnterpriseAgentsUsage.md)
 - [Error](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/Error.md)
 - [ExpandUsageOptions](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/ExpandUsageOptions.md)
 - [Link](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/Link.md)
 - [OrganizationQuota](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/OrganizationQuota.md)
 - [OrganizationQuotaAssignment](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/OrganizationQuotaAssignment.md)
 - [OrganizationQuotaUnassignment](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/OrganizationQuotaUnassignment.md)
 - [OrganizationsQuotasAssign](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/OrganizationsQuotasAssign.md)
 - [OrganizationsQuotasUnassign](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/OrganizationsQuotasUnassign.md)
 - [PaginationLinks](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/PaginationLinks.md)
 - [Quota](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/Quota.md)
 - [Quotas](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/Quotas.md)
 - [QuotasAssignRequest](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/QuotasAssignRequest.md)
 - [QuotasAssignResponse](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/QuotasAssignResponse.md)
 - [QuotasUnassign](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/QuotasUnassign.md)
 - [SelfLinks](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/SelfLinks.md)
 - [TestUsage](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/TestUsage.md)
 - [TestsUsage](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/TestsUsage.md)
 - [UnauthorizedError](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/UnauthorizedError.md)
 - [UnitAllocationSummary](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/UnitAllocationSummary.md)
 - [UnitsByTests](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/UnitsByTests.md)
 - [Usage](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/Usage.md)
 - [UsageDetails](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/UsageDetails.md)
 - [UsageQuota](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/UsageQuota.md)
 - [ValidationError](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/ValidationError.md)
 - [ValidationErrorItem](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-usage/docs/ValidationErrorItem.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="BearerAuth"></a>
### BearerAuth

- **Type**: Bearer authentication


## Author

<a href="mailto:api-team@thousandeyes.com">ThousandEyes API Team </a>


